<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use App\Models\Core\Auth\User;
use App\Repositories\Core\Status\StatusRepository;
use Illuminate\Support\Facades\DB;

class FeedSearchController extends Controller
{
    public function search(User $user) {
        $user->load('teams');

        $status = resolve(StatusRepository::class)->userActive();
        $userQuery = User::query()->select('id' , 'first_name', 'last_name', 'uuid')
            ->with('profilePicture:path,fileable_type,fileable_id', 'teams:id,name');

        $userQuery
            ->where('status_id', $status)
            ->where('id', '!=', auth()->id());

        if(!auth()->user()->isAdmin()) {
            $userQuery->where(function ($qin) use ($user){
                $qin->whereHas('roles', function ($qTeam) use ($user){
                    // admin role.
                    $qTeam->where('role_id', 1);
                })
                ->orWhereHas('teams', function ($qTeam) use ($user){
                    $qTeam->whereIn('team_id', $user->teams()->pluck('id')->toArray());
                    $qTeam->whereIn('team_id', auth()->user()->teams()->pluck('id')->toArray());
                });
            });
        }

        if(request('search')){
            $search = request('search');
            $userQuery
                ->where(function ($qin) use ($search){
                    // admin role.
                    $qin->where('first_name', 'LIKE', "%$search%")
                        ->orWhere('last_name', 'LIKE', "%{$search}%")
//                        ->orWhere('email', 'LIKE', "%$search%")
                        ->orWhereRaw(DB::raw('CONCAT(`first_name`, " ", `last_name`) LIKE ?'), ["%$search%"]);
                });
        }

        return $userQuery->paginate(request('per_page', 5));
    }
}
