<?php

namespace App\Http\Controllers\Application\Post;

use App\Http\Controllers\Controller;
use App\Models\Application\Post\Post;
use App\Models\Core\Auth\User;
use App\Repositories\Core\Status\StatusRepository;
use Illuminate\Pagination\Paginator;

class PostFeedController extends Controller
{
    function postFeed() {
        $team = request('team') ?? null;
        if(!auth()->user()->isAdmin() && in_array($team, auth()->user()->teams()->pluck('id')->toArray())) {
            return new Paginator([], request('per_page', 5), '', ['path' => request()->fullUrl()]);
        }

        $status = resolve(StatusRepository::class)->postPublished();
        return Post::
                with('user:id,first_name,last_name,uuid', 'user.profilePicture:path,fileable_type,fileable_id',
                    'status:id,name',
                    'attachments:path,fileable_type,fileable_id'
                )
                ->withCount(['comments', 'reactions', 'views'])
                ->where('status_id', $status)
//                ->where('user_id', '!=', auth()->id())
                ->ensureUserCanSee()
                ->orderBy('created_at', 'desc')
                ->paginate(request('per_page', 5));
    }

    function userPostFeed(User $user) {
        $status = resolve(StatusRepository::class)->postPublished();
        return Post::
                with('user:id,first_name,last_name,uuid', 'user.profilePicture:path,fileable_type,fileable_id',
                    'status:id,name',
                    'attachments:path,fileable_type,fileable_id'
                )
                ->withCount(['comments', 'reactions', 'views'])
                ->where('status_id', $status)
                ->where('user_id', $user->id)
                ->ensureUserCanSee()
                ->orderBy('created_at', 'desc')
                ->paginate(request('per_page', 5));
    }
}
