<?php

namespace App\Http\Controllers\Application\Post;

use App\Events\NewNotification;
use App\Helpers\Traits\ApplicationFunction;
use App\Http\Controllers\Controller;
use App\Http\Requests\Application\Post\CommentReactRequest;
use App\Http\Requests\Application\Post\PostReactRequest;
use App\Http\Requests\Application\Post\ReplyReactRequest;
use App\Models\Application\Post\CommentReply;
use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostComment;
use App\Services\Application\Post\PostReactionService;

class PostReactionController extends Controller
{
    use ApplicationFunction;
    public function __construct(PostReactionService $service)
    {
        $this->service = $service;
    }

    function reactToPost(Post $post, PostReactRequest $request) {
        // react
        $reacted = $this->service
            ->reactTo($post);

        if($reacted) {
            $message = auth()->user()->full_name." reacted to your post ".$this->textShorter($post->body);
            broadcast(new NewNotification($post->user_id, $message))->toOthers();
        }

        // return success
        $post->fresh();
        $post->loadCount(['reactions']);
        return custom_data_response('reacted_to_post',
            [
                'reactions_count' => $post->reactions_count,
                'reacted' => $post->reacted
            ]);
    }

    function reactToComment(PostComment $post_comment, CommentReactRequest $request) {
        // react
        $reacted = $this->service
            ->reactTo($post_comment);

        if($reacted) {
            $message = auth()->user()->full_name." reacted to your comment ".$this->textShorter($post_comment->comment);
            broadcast(new NewNotification($post_comment->user_id, $message))->toOthers();
        }

        // return success
        $post_comment->fresh();
        $post_comment->loadCount(['reactions']);
        return custom_data_response('reacted_to_comment',
            [
                'reactions_count' => $post_comment->reactions_count,
                'reacted' => $post_comment->reacted
            ]);
    }

    function reactToReply(CommentReply $comment_reply, ReplyReactRequest $request) {
        // react
        $reacted = $this->service
            ->reactTo($comment_reply);

        if($reacted) {
            $message = auth()->user()->full_name." reacted to your reply ".$this->textShorter($comment_reply->comment);
            broadcast(new NewNotification($comment_reply->user_id, $message))->toOthers();
        }

        // return success
        $comment_reply->fresh();
        $comment_reply->loadCount(['reactions']);
        return custom_data_response('reacted_to_reply', [
            'reactions_count' => $comment_reply->reactions_count,
                'reacted' => $comment_reply->reacted
            ]);
    }
}
