<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use App\Models\Application\Post\Post;
use App\Models\Application\User\Team;
use App\Models\Core\Auth\User;
use App\Repositories\Core\Status\StatusRepository;
use Illuminate\Support\Facades\DB;

class SelectableController extends Controller
{
    public function teams() {
        return Team::active()
            ->get(['id', 'name']);
    }
    public function userTeams(User $user) {
        if(auth()->id() == $user->id && $user->isAdmin()) {
            return Team::active()
                ->get(['id', 'name']);
        }
        return $user->teams;
    }

    public function relatedUsers(User $user): \Illuminate\Database\Eloquent\Collection|array
    {
        $user->load('teams');

        $status = resolve(StatusRepository::class)->userActive();
        $userQuery = User::query()->select('id' , 'first_name', 'last_name', 'uuid')
            ->with('profilePicture:path,fileable_type,fileable_id');

        $userQuery
            ->where('status_id', $status)
            ->where('id', '!=', auth()->id());

        if(!auth()->user()->isAdmin()) {
            $userQuery->whereHas('roles', function ($qTeam) use ($user){
                // admin role.
                $qTeam->where('role_id', 1);
            })
            ->orWhereHas('teams', function ($qTeam) use ($user){
                $qTeam->whereIn('team_id', $user->teams()->pluck('id')->toArray());
                $qTeam->whereIn('team_id', auth()->user()->teams()->pluck('id')->toArray());
            })
            ->where('status_id', $status)
            ->where('id', '!=', auth()->id());
        }

        return $userQuery
            ->get();
    }

    public function userGalleries(User $user): array
    {
        $status = resolve(StatusRepository::class)->postPublished();
        $posts = Post::with(
                    'attachments:path,fileable_type,fileable_id',
                )
                ->where('status_id', $status)
                ->where('user_id', $user->id)
                ->ensureUserCanSee()
                ->get();
        $attachments = [];
        foreach ($posts as $post) {
            $attachments = array_merge($attachments, $post->attachments->toArray());
        }
        return $attachments;
    }
}
