<?php

namespace App\Http\Controllers\Application\User;

use App\Filters\Application\User\TeamFilter;
use App\Http\Controllers\Controller;
use App\Http\Requests\Application\User\TeamRequest;
use App\Models\Application\User\Team;
use App\Repositories\Core\Status\StatusRepository;
use App\Services\Application\User\TeamService;

class TeamController extends Controller
{
    public function __construct(TeamService $service, TeamFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        return $this->service
            ->filters($this->filter)
            ->with('status:id,name,class', 'manager:id,first_name,last_name',
                'users:id,first_name,last_name,email', 'users.profilePicture:id,path,fileable_type,fileable_id')
            ->latest('id')
            ->paginate(request()->get('per_page', 10));
    }

    public function store(TeamRequest $request)
    {
        $status = resolve(StatusRepository::class)->teamActive();

        $attributes = array_merge($request
            ->only('name', 'description'),
            [
                'status_id' => $status,
                'manager_id' => auth()->id(),
            ]
        );

        $team = $this->service
            ->setAttributes($attributes)
            ->save();

        return created_responses('team', ['team' => $team]);
    }

    public function show(Team $team)
    {
        return $team->load('status', 'manager');
    }

    public function update(Team $team, TeamRequest $request)
    {
        $this->service
            ->setAttributes(
                $request->only('name', 'description')
            )
            ->setModel($team)
            ->save();

        return updated_responses('team', ['team' => $team]);
    }

    public function destroy(Team $team)
    {
        $this->service
            ->setModel($team)
            ->delete();

        return deleted_responses('team');
    }
}
