<?php

namespace App\Http\Requests\Application\Post;

use App\Http\Requests\BaseRequest;
use App\Models\Application\User\TeamUser;

class ReplyReactRequest extends BaseRequest
{
    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'reaction' => 'required|exists:reactions,reaction',
        ];
    }

    /**
     * Configure the validator instance.
     *
     * @param  \Illuminate\Validation\Validator  $validator
     * @return void
     */
    public function withValidator($validator): void
    {
        $validator->after(function ($validator) {
            if (!$this->checkIfAllowed()) {
                $validator->errors()->add('reaction', 'You are not allowed!');
            }
        });
    }

    public function checkIfAllowed() {
        if(auth()->user()->isAdmin()) return true;
        $this->comment_reply->load('parentComment.post', 'parentComment.post.teams');
        if($this->comment_reply->parentComment->post->user_id == auth()->id()) return true;
        if($this->comment_reply->parentComment->post->shared_with == 'public') return true;

        $team_ids = $this->comment_reply->parentComment->post->teams->pluck('id')->toArray();
        if(TeamUser::whereIn('team_id', $team_ids)->where('user_id', auth()->id())->first()) return true;

        return false;
    }
}
