<?php

namespace App\Models\Application\Post;

use App\Models\Application\Post\Traits\PostRelationshipTrait;
use App\Models\Core\BaseModel;
use Database\Factories\Application\Post\PostFactory;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Str;

class Post extends BaseModel
{
    use PostRelationshipTrait, HasFactory, SoftDeletes;
    protected $fillable = [
        'uuid', 'user_id', 'body', 'status_id', 'shared_with', 'shared_post_id'
    ];

    public static function boot() : void
    {
        parent::boot();
        static::creating(function ($model) {
            return $model->fill([
                'uuid' => Str::uuid(),
            ]);
        });
    }

    protected $appends = ['reacted'];

    /**
     * Create a new factory instance for the model.
     *
     * @return \Illuminate\Database\Eloquent\Factories\Factory
     */
    protected static function newFactory(): \Illuminate\Database\Eloquent\Factories\Factory
    {
        return PostFactory::new();
    }

    /**
     * Get the user's first name.
     *
     * @return \Illuminate\Database\Eloquent\Casts\Attribute
     */
    protected function reacted(): Attribute
    {
        return Attribute::make(
            get: function ($value) {
                if(!auth()->id()) return false;
                return (bool)$this->reactions()->where('user_id', auth()->id())->first();
            },
        );
    }

    public function scopeEnsureUserCanSee(Builder $query) {
        $team = request('team') ?? null;
        if($team) {
            return $query->where('shared_with', 'team')
                ->whereHas('teams', function ($qTeam) use ($team){
                    $qTeam->where('team_id', $team);
                });
        }

        if(auth()->user()->isAdmin()) {
            return $query;
        }

        return $query->where('shared_with', 'public')
            ->orWhere(function ($qIn) {
                $qIn->where('shared_with', 'team')
                    ->whereHas('teams', function ($qTeam) {
                        $qTeam->whereIn('team_id', auth()->user()->teams()->pluck('id')->toArray());
                    });
            });

    }
}
