<?php

namespace App\Models\Application\Post;

use App\Models\Application\Traits\Relationships\PostRelationship;
use App\Models\Application\Traits\Relationships\UserRelationship;
use App\Models\Core\BaseModel;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class PostComment extends BaseModel
{
    use PostRelationship, UserRelationship, SoftDeletes;
    protected $fillable = [
        'post_id', 'user_id', 'comment'
    ];

    protected $appends = ['reacted'];

    /**
     * Get the user's first name.
     *
     * @return \Illuminate\Database\Eloquent\Casts\Attribute
     */
    protected function reacted(): Attribute
    {
        return Attribute::make(
            get: function ($value) {
                if(!auth()->id()) return false;
                return (bool)$this->reactions()->where('user_id', auth()->id())->first();
            },
        );
    }

    public function replies(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(CommentReply::class, 'comment_id');
    }

    public function reactions(): MorphMany
    {
        return $this->morphMany(PostReaction::class, 'reactable');
    }
}
