<?php

namespace App\Models\Application\Post\Traits;

use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostComment;
use App\Models\Application\Post\PostReaction;
use App\Models\Application\Post\PostTeam;
use App\Models\Application\Post\PostView;
use App\Models\Application\Traits\Relationships\UserRelationship;
use App\Models\Application\User\Team;
use App\Models\Core\File\File;
use App\Models\Core\Traits\StatusRelationship;
use Illuminate\Database\Eloquent\Relations\MorphMany;

trait PostRelationshipTrait
{
    use StatusRelationship, UserRelationship;

    public function comments(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(PostComment::class);
    }

    public function reactions(): MorphMany
    {
        return $this->morphMany(PostReaction::class, 'reactable');
    }

    public function views(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(PostView::class);
    }

    public function teams(): \Illuminate\Database\Eloquent\Relations\BelongsToMany
    {
        return $this->belongsToMany(
            Team::class,
            'post_teams',
            'post_id',
            'team_id'
        )->using(PostTeam::class);
    }

    public function sharedPost(): \Illuminate\Database\Eloquent\Relations\BelongsTo
    {
        return $this->belongsTo(Post::class, 'shared_post_id', 'id');
    }

    public function attachments(): MorphMany
    {
        return $this->morphMany(File::class, 'fileable');
    }
}
