<?php

namespace App\Models\Application\User;

use App\Models\Core\Auth\User;
use App\Models\Core\BaseModel;
use App\Models\Core\Traits\StatusRelationship;
use App\Repositories\Core\Status\StatusRepository;
use Illuminate\Database\Eloquent\Builder;

class Team extends BaseModel
{
    use StatusRelationship;

    protected $fillable = [
        'name', 'description', 'manager_id', 'status_id'
    ];

    public function manager()
    {
        return $this->belongsTo(User::class, 'manager_id');
    }

    public function users()
    {
        return $this->belongsToMany(
            User::class,
            'team_user',
            'team_id',
            'user_id'
        )->withPivot('joined_at')
            ->using(TeamUser::class);
    }

    public function scopeActive(Builder $builder)
    {
        $builder->where('status_id', resolve(StatusRepository::class)->teamActive());
    }

    public function isInActive()
    {
        return optional($this->status)->name === 'status_inactive';
    }

    public function isActive()
    {
        return optional($this->status)->name === 'status_active';
    }
}
