<?php

namespace App\Notifications\Application;

use App\Mail\Tag\Application\ReactionTag;
use App\Models\Application\Post\CommentReply;
use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostComment;
use App\Notifications\BaseNotification;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;

class ReactionNotification extends BaseNotification implements ShouldQueue
{
    use Queueable;

    public function __construct($templates, $via, $reaction, $auth = null)
    {
        $this->templates = $templates;
        $this->via = $via;
        $this->model = $reaction;
        $this->auth = $auth ?? auth()->user();
        $this->tag = ReactionTag::class;
        parent::__construct();
    }

    public function parseNotification()
    {
        $this->mailView = 'notification.mail.template';
        $this->databaseNotificationUrl = route('core.dashboard');

        $reaction = $this->getReaction();

        $this->mailSubject = optional($this->template()->mail())->parseSubject([
            '{action_by}' => $this->auth->full_name,
            '{app_name}' => config('settings.application.company_name'),
            '{reaction}' => $reaction,
        ]);

        $this->databaseNotificationContent = optional($this->template()->database())->parse([
            '{action_by}' => $this->auth->full_name,
            '{reaction}' => $reaction,
        ]);
    }

    public function getReaction(): string {
        $reaction = $this->model;
        $reaction->load('reactable');
        switch ($reaction->reactable_type) {
            case Post::class:
                $prefix = 'post';
//                $model = Post::query()->select('body')->where('id', $reaction->reactable_id)->first();
                $text = $reaction->reactable->body;
                break;
            case PostComment::class:
                $prefix = 'comment';
//                $model = PostComment::query()->select('comment')->find($reaction->reactable_id);
                $text = $reaction->reactable->comment;
                break;
            case CommentReply::class:
                $prefix = 'reply';
//                $model = CommentReply::query()->select('comment')->find($reaction->reactable_id);
                $text = $reaction->reactable->comment;
                break;
            default:
                $prefix = '';
                $text = '';
                break;
        }
        return $prefix.' '.((strlen($text) > 20)? (substr($text,0, 20).' ...') : $text);
    }
}
