<?php

namespace App\Notifications\Application;

use App\Mail\Tag\Application\ReplyTag;
use App\Notifications\BaseNotification;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;

class ReplyNotification extends BaseNotification implements ShouldQueue
{
    use Queueable;

    public function __construct($templates, $via, $reaction, $auth = null)
    {
        $this->templates = $templates;
        $this->via = $via;
        $this->model = $reaction;
        $this->auth = $auth ?? auth()->user();
        $this->tag = ReplyTag::class;
        parent::__construct();
    }

    public function parseNotification()
    {
        $this->mailView = 'notification.mail.template';
        $this->databaseNotificationUrl = route('core.dashboard');

        $comment = $this->getComment();
        $reply = $this->getReply();

        $this->mailSubject = optional($this->template()->mail())->parseSubject([
            '{action_by}' => $this->auth->full_name,
            '{app_name}' => config('settings.application.company_name'),
            '{comment}' => $comment,
            '{reply}' => $reply,
        ]);

        $this->databaseNotificationContent = optional($this->template()->database())->parse([
            '{action_by}' => $this->auth->full_name,
            '{comment}' => $comment,
            '{reply}' => $reply,
        ]);
    }

    public function getComment(): string {
        $this->model->load('parentComment');
        $text = $this->model->parentComment->comment;
        return ((strlen($text) > 20)? (substr($text,0, 20).' ...') : $text);
    }

    public function getReply(): string {
        $text = $this->model->comment;
        return ((strlen($text) > 20)? (substr($text,0, 20).' ...') : $text);
    }
}
