<?php

namespace App\Services\Application\Dashboard;

use App\Services\Core\BaseService;
use Carbon\Carbon;

class DashboardService extends BaseService
{

    public function postOverview($posts)
    {
        // Posts Overview

        $week_container = array_fill(0, 7, 0);
        $public_week_map = $week_container;
        $team_week_map = $week_container;
        $total_week_map = $week_container;

        // Month of Year Section
        $year_container = array_fill(0, 12, 0);
        $public_year_map = $year_container;
        $team_year_map = $year_container;
        $total_year_map = $year_container;

        $check_last_or_this_month = request()->has('last_month')
            ? now()->subMonth()->daysInMonth
            : now()->daysInMonth;
        $month_container = array_fill(1, $check_last_or_this_month, 0);
        $month_public = $month_container;
        $month_team = $month_container;
        $month_total = $month_container;

        // Total Post Count
        $total_posts = $posts->count();

        // Public Post Count
        $public_posts = $posts->where('shared_with', 'public')->count();

        // Team Post Count
        $team_posts = $posts->where('shared_with', 'team')->count();

        // Status public Filter
        $public_posts_filter = $posts->where('shared_with', 'public')->pluck('created_at');

        list($public_week_map, $month_public, $public_year_map)
            = $this->statusFilters($public_posts_filter, $public_week_map, $month_public, $public_year_map);

        // Status Team Filter
        $team_posts_filter = $posts->where('shared_with', 'team')->pluck('created_at');

        list($team_week_map, $month_team, $team_year_map)
            = $this->statusFilters($team_posts_filter, $team_week_map, $month_team, $team_year_map);

        // Total Filter
        $totalFilter = $posts->pluck('created_at');

        list($total_week_map, $month_total, $total_year_map)
            = $this->statusFilters($totalFilter, $total_week_map, $month_total, $total_year_map);

        $posts_overview = [];

        if (\request()->has('last_seven_days') || \request()->has('this_week') || \request()->has('last_week')) {
            array_push(
                $posts_overview,
                $public_week_map,
                $team_week_map,
                $total_week_map
            );
        } elseif (\request()->has('this_month') || \request()->has('last_month')) {
            array_push(
                $posts_overview,
                collect($month_public)->values(),
                collect($month_team)->values(),
                collect($month_total)->values()
            );
        } elseif (\request()->has('this_year') || \request()->has('total')) {
            array_push(
                $posts_overview,
                $public_year_map,
                $team_year_map,
                $total_year_map
            );
        }

        return [
            'post_overview' => $posts_overview,
            'total_post' => $total_posts,
            'public_post' => $public_posts,
            'team_post' => $team_posts,
        ];
    }

    public function statusFilters($filters, $WeekMap, $month, $YearMap)
    {
        foreach ($filters as $value) {
            if (\request()->has('last_seven_days') || \request()->has('this_week') || \request()->has('last_week')) {
                ++$WeekMap[Carbon::parse($value)->dayOfWeek];
            } elseif (\request()->has('this_month') || \request()->has('last_month')) {
                ++$month[Carbon::parse($value)->day];
            } elseif (\request()->has('this_year') || \request()->has('total')) {
                ++$YearMap[Carbon::parse($value)->month - 1];
            }
        }
        return [$WeekMap, $month, $YearMap];
    }
}
