<?php

namespace App\Services\Application\Post;

use App\Events\NewNotification;
use App\Helpers\Core\Traits\FileHandler;
use App\Helpers\Core\Traits\HasWhen;
use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostReaction;
use App\Models\Application\Post\Reaction;
use App\Notifications\Application\ReactionNotification;
use App\Services\Core\BaseService;
use ReflectionClass;

class PostReactionService extends BaseService
{
    use HasWhen, FileHandler;

    public function __construct(PostReaction $post_reaction)
    {
        $this->model = $post_reaction;
    }

    function reactTo($reactable) {
        $reaction = Reaction::where('reaction', request('reaction', "👍"))->first();
        $reflection = new ReflectionClass($reactable);

        $reacted = $this->model
            ->where('reactable_type', $reflection->getName())
            ->where('reactable_id', $reactable->id)
            ->where('user_id', auth()->id())
            ->where('reaction_id', $reaction->id)
            ->first();
        if($reacted) {
            // have same reaction
            $reacted->delete();
            return false;
        }

        $reacted = $this->model
            ->where('reactable_type', $reflection->getName())
            ->where('reactable_id', $reactable->id)
            ->where('user_id', auth()->id())
            ->first();
        if($reacted) {
            // have different reaction
            $reacted->update([
                'reaction_id' => $reaction->id
            ]);
            return true;
        }

        // have no reaction
        $reaction = $this->model->create([
            'user_id' => auth()->id(),
            'reactable_type' => $reflection->getName(),
            'reactable_id' => $reactable->id,
            'reaction_id' => $reaction->id
        ]);

        $this->setModel($reaction);
        $this->notify([$reactable->user_id]);
        return true;
    }

    public function notify($audiences, $auth = null) {
        if (!$auth) {
            $auth = auth()->user();
        }

        notify()
            ->on('user_reacted')
            ->with([$this->model, $auth])
            ->audiences($audiences)
            ->send(ReactionNotification::class);
    }
}
