<?php

namespace App\Services\Application\Post;

use App\Helpers\Core\Traits\FileHandler;
use App\Helpers\Core\Traits\HasWhen;
use App\Models\Application\Post\Post;
use App\Models\Application\User\TeamUser;
use App\Models\Core\File\File;
use App\Notifications\Application\PostNotification;
use App\Repositories\Core\Status\StatusRepository;
use App\Services\Core\BaseService;
use Illuminate\Http\UploadedFile;

class PostService extends BaseService
{
    use HasWhen, FileHandler;

    public function __construct(Post $post)
    {
        $this->model = $post;
    }
    public function syncTeams($teams = []): PostService
    {
        $this->model->teams()->sync($teams);
        return $this;
    }

    public function saveAttachments($attachments): self
    {
        if ($attachments && count($attachments) > 0) {
            foreach ($attachments as $attachment) {
                if(!($attachment instanceof UploadedFile)) continue;
                $this->model->attachments()->save(new File([
                    'path' => $this->storeFile($attachment, 'post'),
                    'type' => 'post',
                ]));
            }
        }
        return $this;
    }

    public function removeAttachments($remove_attachments): self
    {
        if ($remove_attachments && count($remove_attachments) > 0) {
            foreach ($remove_attachments as $remove_attachment) {
                $decoded_attachment = json_decode($remove_attachment);
                $attachment = $this->model->attachments()->find(optional($decoded_attachment)->id);
                if($attachment) {
                    $this->deleteImage(optional($attachment)->path);
                    $attachment->delete();
                }
            }
        }
        return $this;
    }

    public function notify($auth = null) {
        // notify team users when post shared with team.
        if($this->model->shared_with == 'public') return;

        if (!$auth) {
            $auth = auth()->user();
        }

        notify()
            ->on('post_created')
            ->with([$this->model, $auth])
            ->mergeAudiences($this->getAudiences())
            ->send(PostNotification::class);
    }

    public function getAudiences() {
        $post = $this->model;
        $post->load('teams');
        $teamIds = $post->teams->pluck('id')->toArray();

        $status = resolve(StatusRepository::class)->userActive();
        return TeamUser::whereIn('team_id', $teamIds)
            ->whereHas('user', function ($qTeam) use ($status){
                // active user.
                $qTeam->where('status_id', $status);
            })
            ->where('user_id', '!=', $post->user_id)
            ->select('user_id')->distinct()->get()->pluck('user_id')->toArray();
    }
}
