<?php
namespace Database\Seeders\Application\Post;

use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostComment;
use App\Models\Application\User\TeamUser;
use App\Models\Core\Auth\User;
use Faker\Factory as Faker;
use Illuminate\Database\Seeder;

class PostCommentTableSeeder extends Seeder
{
    /**
     * Run the database seeders.
     *
     * @return void
     */
    public function run()
    {
        $faker = Faker::create();
        // if it shared with team, then set teams.
        $postComments = [];
        $posts = Post::get();
        foreach($posts as $post) {
            if($post->shared_with == 'team') {
                $teamIds = TeamUser::where('user_id', $post->user_id)->pluck('team_id')->toArray();
                $userIds = TeamUser::whereIn('team_id', $teamIds)->pluck('user_id')->toArray();
            } else {
                $userIds = User::pluck('id')->toArray();
            }

            $commentUserIds = count($userIds) > 0 ? $faker->randomElements($userIds, rand(0, min(count($userIds)-1, 5))) : [];
            foreach ($commentUserIds as $userId) {
                $postComments[] = [
                    'post_id' => $post->id,
                    'user_id' => $userId,
                    'comment' => $faker->paragraph,
                    'created_at' => now(),
                    'updated_at' => now(),
                ];
            }
        }
        PostComment::insert($postComments);
    }
}
