<?php
namespace Database\Seeders\Application\Post;

use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostReaction;
use App\Services\Application\Post\CommentReplyService;
use App\Services\Application\Post\PostCommentService;
use App\Services\Application\Post\PostReactionService;
use App\Services\Application\Post\PostService;
use Illuminate\Database\Seeder;

class PostNotificationSeeder extends Seeder
{
    /**
     * Run the database seeders.
     *
     * @return void
     */
    public function run()
    {
        // only admin and user reactions for user_id, 1,2
        $posts = Post::with(
            'user',
            'comments', 'comments.user',
            'comments.replies', 'comments.replies.user',
        )->get();
        foreach ($posts as $post) {
            if(in_array($post->user_id, [1,2])) {
                resolve(PostService::class)->setModel($post)->notify($post->user);
            }
            foreach ($post->comments as $comment) {
                if(in_array($comment->user_id, [1,2])) {
                    resolve(PostCommentService::class)->setModel($comment)->notify([$post->user_id], $comment->user);
                }
                foreach ($comment->replies as $reply) {
                    if(in_array($reply->user_id, [1,2])) {
                        resolve(CommentReplyService::class)->setModel($reply)->notify([$comment->user_id], $reply->user);
                    }
                }
            }
        }

        // only admin and user reactions
        $reactions = PostReaction::with('reactable', 'user')->whereIn('user_id', [1,2])->get();
        foreach ($reactions as $reaction) {
            if($reaction->user_id == $reaction->reactable->user_id) continue;
            resolve(PostReactionService::class)->setModel($reaction)->notify([$reaction->reactable->user_id], $reaction->user);
            echo " .";
        }
        echo "\n";
    }
}
