<?php
namespace Database\Seeders\Application\Post;

use App\Models\Application\Post\CommentReply;
use App\Models\Application\Post\Post;
use App\Models\Application\Post\PostComment;
use App\Models\Application\Post\PostReaction;
use App\Models\Application\Post\Reaction;
use App\Models\Application\User\TeamUser;
use App\Models\Core\Auth\User;
use Faker\Factory as Faker;
use Illuminate\Database\Seeder;

class PostReactionTableSeeder extends Seeder
{
    /**
     * Run the database seeders.
     *
     * @return void
     */
    public function run()
    {
        $faker = Faker::create();
        // if it shared with team, then set teams.
        $reactions = Reaction::pluck('id')->toArray();
        $posts = Post::with('comments', 'comments.replies')->get();
        foreach($posts as $post) {
            $postReactions = [];
            if($post->shared_with == 'team') {
                $teamIds = TeamUser::where('user_id', $post->user_id)->pluck('team_id')->toArray();
                $userIds = TeamUser::whereIn('team_id', $teamIds)->pluck('user_id')->toArray();
            } else {
                $userIds = User::pluck('id')->toArray();
            }

            // for post.
            $reactionUserIds = count($userIds) > 0 ? $faker->randomElements($userIds, rand(0, min(count($userIds)-1, 5))) : [];
            foreach ($reactionUserIds as $userId) {
                $postReactions[] = [
                    'reactable_type' => Post::class,
                    'reactable_id' => $post->id,
                    'user_id' => $userId,
                    'reaction_id' => $faker->randomElement($reactions),
                    'created_at' => now(),
                    'updated_at' => now(),
                ];
            }

            foreach($post->comments as $comment) {
                // for comment.
                $reactionUserIds = count($userIds) > 0 ? $faker->randomElements($userIds, rand(1, count($userIds)-1)) : [];
                foreach ($reactionUserIds as $userId) {
                    $postReactions[] = [
                        'reactable_type' => PostComment::class,
                        'reactable_id' => $comment->id,
                        'user_id' => $userId,
                        'reaction_id' => $faker->randomElement($reactions),
                        'created_at' => now(),
                        'updated_at' => now(),
                    ];
                }
                foreach($comment->replies as $reply) {
                    // for reply.
                    $reactionUserIds = count($userIds) > 0 ? $faker->randomElements($userIds, rand(1, count($userIds)-1)) : [];
                    foreach ($reactionUserIds as $userId) {
                        $postReactions[] = [
                            'reactable_type' => CommentReply::class,
                            'reactable_id' => $reply->id,
                            'user_id' => $userId,
                            'reaction_id' => $faker->randomElement($reactions),
                            'created_at' => now(),
                            'updated_at' => now(),
                        ];
                    }
                }
            }
            PostReaction::insert($postReactions);
        }
    }
}
