<?php
namespace Database\Seeders\Auth;

use App\Models\Core\Auth\Permission;
use App\Models\Core\Auth\Type;
use Database\Seeders\Traits\DisableForeignKeys;
use Illuminate\Database\Seeder;

class PermissionTableSeeder extends Seeder
{
    use DisableForeignKeys;
    /**
     * Run the database seeders.
     *
     * @return void
     */
    public function run()
    {
        $this->disableForeignKeys();
        Permission::query()->truncate();
        $appId = Type::findByAlias('app')->id;

        $permissions = [
            //users
            [
                'name' => 'view_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'manage_dashboard',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            [
                'name' => 'create_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'update_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'delete_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'cancel_user_invitation',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'attach_roles_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'detach_roles_users',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            [
                'name' => 'invite_user',
                'type_id' => $appId,
                'group_name' => 'users'
            ],
            //end users
            //roles
            [
                'name' => 'view_roles',
                'type_id' => $appId,
                'group_name' => 'roles'
            ],
            [
                'name' => 'create_roles',
                'type_id' => $appId,
                'group_name' => 'roles'
            ],
            [
                'name' => 'update_roles',
                'type_id' => $appId,
                'group_name' => 'roles'
            ],
            [
                'name' => 'delete_roles',
                'type_id' => $appId,
                'group_name' => 'roles'
            ],
            [
                'name' => 'attach_users_to_roles',
                'type_id' => $appId,
                'group_name' => 'roles'
            ],
            //permission
            [
                'name' => 'attach_permissions_roles',
                'type_id' => $appId,
                'group_name' => 'permissions'
            ],
            [
                'name' => 'detach_permissions_roles',
                'type_id' => $appId,
                'group_name' => 'permissions'
            ],

            //settings
            [
                'name' => 'view_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            [
                'name' => 'update_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            [
                'name' => 'update_delivery_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            [
                'name' => 'view_delivery_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            [
                'name' => 'view_notification_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            [
                'name' => 'update_notification_settings',
                'type_id' => $appId,
                'group_name' => 'settings'
            ],
            //end of settings
            // dashboard permissions
            [
                'name' => 'view_posts_overview',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            [
                'name' => 'view_reaction_overview',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            [
                'name' => 'view_user_summary',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            [
                'name' => 'view_post_summary',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            [
                'name' => 'view_top_3_post_creator',
                'type_id' => $appId,
                'group_name' => 'dashboard'
            ],
            // end of dashboard permissions

            //Notification Templates
            [
                'name' => 'view_notification_templates',
                'type_id' => $appId,
                'group_name' => 'templates'
            ],
            [
                'name' => 'create_notification_templates',
                'type_id' => $appId,
                'group_name' => 'templates'
            ],
            [
                'name' => 'update_notification_templates',
                'type_id' => $appId,
                'group_name' => 'templates'
            ],
            [
                'name' => 'delete_notification_templates',
                'type_id' => $appId,
                'group_name' => 'templates'
            ],
            [
                'name' => 'view_activity_logs',
                'type_id' => $appId,
                'group_name' => 'log'
            ],

            //Example table permission
//            [
//                'name' => 'view_example',
//                'type_id' => $appId,
//                'group_name' => 'example'
//            ],
//            [
//                'name' => 'create_example',
//                'type_id' => $appId,
//                'group_name' => 'example'
//            ],
//            [
//                'name' => 'update_example',
//                'type_id' => $appId,
//                'group_name' => 'example'
//            ],
//            [
//                'name' => 'delete_example',
//                'type_id' => $appId,
//                'group_name' => 'example'
//            ],

            // Teams
            [
                'name' => 'create_teams',
                'type_id' => $appId,
                'group_name' => 'team'
            ],
            [
                'name' => 'view_teams',
                'type_id' => $appId,
                'group_name' => 'team'
            ],
            [
                'name' => 'update_teams',
                'type_id' => $appId,
                'group_name' => 'team'
            ],
            [
                'name' => 'delete_teams',
                'type_id' => $appId,
                'group_name' => 'team'
            ],
            [
                'name' => 'update_teams_status',
                'type_id' => $appId,
                'group_name' => 'team'
            ],

        ];

        $this->enableForeignKeys();
        Permission::query()->insert($permissions);
    }
}
