<?php

use App\Http\Controllers\Admin\Navigation\NavigationController;
use App\Http\Controllers\Core\LanguageController;
use App\Http\Controllers\InstallDemoDataController;
use App\Http\Middleware\PermissionMiddleware;
use Illuminate\Support\Facades\Route;

Route::redirect('/', 'feed', 301);

/*
 * for documentation purpose
 */

Route::group(['middleware' => ['auth', 'authorize']], function () {
    Route::view('/feed', 'client.feed')->name('client.feed');
    Route::view('/teams/{team}', 'client.teams')->name('teams.single');
    Route::get('/profile/{user:uuid}', [NavigationController::class, 'userProfile'])->name('client.profile');
    Route::get('/gallery/{user:uuid}', [NavigationController::class, 'userGallery'])->name('client.gallery');
});

//Route::get("doc/core/components", [\App\Http\Controllers\DocumentationController::class, 'index']);
//Route::get("doc/core/components/{component_name}", [\App\Http\Controllers\DocumentationController::class, 'show']);
//end

//Route::post('test-component', [\App\Http\Controllers\TestingController::class, 'test']);
//Route::get('test-component', [\App\Http\Controllers\TestingController::class, 'testValue']);
//Route::get('get-test-chart', [\App\Http\Controllers\TestingController::class, 'getTestChart']);
//Route::get('test-search-select', [\App\Http\Controllers\TestingController::class, 'getTestSearchSelect']);

//Route::get('dynamic-contnent/{id}', [\App\Http\Controllers\TestingController::class, 'getDynamicValue']);
//
//Route::post('store', [\App\Http\Controllers\TestingController::class, 'store'])->name('store');
//Route::get('test-value', [\App\Http\Controllers\TestingController::class, 'getTestValue'])->name('test-value');
//Route::get('test-cards', [\App\Http\Controllers\TestingController::class, 'getCardDataForTest'])->name('test-cards');
//Route::get('test-calendar-events', [\App\Http\Controllers\TestingController::class, 'getCalendarEventForTest'])->name('test-calendar-events');
//Route::get('test-api', [\App\Http\Controllers\TestingController::class, 'search_and_select'])->name('test-api');


// Switch between the included languages
Route::get('lang/{lang}', [LanguageController::class, 'swap'])->name('language.change');

/*
 * All login related route will be go there
 * Only guest user can access this route
 */

Route::group(['middleware' => ['guest', 'app.installed'], 'prefix' => 'users'], function () {
    include_route_files(__DIR__ . '/user/');
});

Route::group(['middleware' => ['guest', 'app.installed'], 'prefix' => 'admin/users'], function () {
    include_route_files(__DIR__ . '/login/');
});

/**
 * This route is only for brand redirection
 * And for some additional route
 */
Route::group(['prefix' => 'admin', 'middleware' => ['auth', 'authorize']], function () {
    include __DIR__ . '/additional.php';
});

Route::group(['middleware' => ['auth', 'authorize'], 'prefix' => 'application-api'], function () {
    include_route_files(__DIR__ . '/application/');
});

/**
 * Backend Routes
 * Namespaces indicate folder structure
 * All your route in sub file must have a name with not more than 2 index
 * Example: brand.index or dashboard
 * See @var PermissionMiddleware for more information
 */
Route::group(['prefix' => 'admin', 'middleware' => 'admin', 'as' => 'core.'], function () {

    /*
     * (good if you want to allow more than one group in the core,
     * then limit the core features by different roles or permissions)
     *
     * Note: Administrator has all permissions so you do not have to specify the administrator role everywhere.
     * These routes can not be hit if the password is expired
     */
    include_route_files(__DIR__ . '/core/');
});

//Admin Route Here
include_route_files(__DIR__ . '/admin/');

Route::any('install-demo-data', [InstallDemoDataController::class, 'run'])
    ->name('install-demo-data');
